about summary refs log tree commit diff
path: root/app/javascript/flavours
diff options
context:
space:
mode:
authorbeatrix <beatrix.bitrot@gmail.com>2018-04-26 11:34:14 -0400
committerGitHub <noreply@github.com>2018-04-26 11:34:14 -0400
commitf4ed38272be7cce814e3d3e7e5a2d1f352279e19 (patch)
tree4e26499478b18d2338be90f21428f1bd76481b89 /app/javascript/flavours
parent8f12afb5996c58ddf41ceaa20f6c4e036273d3a6 (diff)
parentb383c0688a0939d25b9184e61dac72cda71f6926 (diff)
Merge pull request #401 from ThibG/glitch-soc/features/unfold-thread
Port the “unfold thread” feature from Mastodon's UI to glitch-soc flavour
Diffstat (limited to 'app/javascript/flavours')
-rw-r--r--app/javascript/flavours/glitch/components/column_header.js34
-rw-r--r--app/javascript/flavours/glitch/components/status.js78
-rw-r--r--app/javascript/flavours/glitch/components/status_content.js11
-rw-r--r--app/javascript/flavours/glitch/components/status_icons.js6
-rw-r--r--app/javascript/flavours/glitch/features/status/components/detailed_status.js7
-rw-r--r--app/javascript/flavours/glitch/features/status/index.js27
-rw-r--r--app/javascript/flavours/glitch/features/ui/components/column_header.js20
-rw-r--r--app/javascript/flavours/glitch/reducers/statuses.js20
-rw-r--r--app/javascript/flavours/glitch/styles/components/columns.scss8
9 files changed, 126 insertions, 85 deletions
diff --git a/app/javascript/flavours/glitch/components/column_header.js b/app/javascript/flavours/glitch/components/column_header.js
index ae90b6f81..bfad6467d 100644
--- a/app/javascript/flavours/glitch/components/column_header.js
+++ b/app/javascript/flavours/glitch/components/column_header.js
@@ -23,12 +23,12 @@ export default class ColumnHeader extends React.PureComponent {
 
   static propTypes = {
     intl: PropTypes.object.isRequired,
-    title: PropTypes.node.isRequired,
-    icon: PropTypes.string.isRequired,
+    title: PropTypes.node,
+    icon: PropTypes.string,
     active: PropTypes.bool,
     localSettings : ImmutablePropTypes.map,
     multiColumn: PropTypes.bool,
-    focusable: PropTypes.bool,
+    extraButton: PropTypes.node,
     showBackButton: PropTypes.bool,
     notifCleaning: PropTypes.bool, // true only for the notification column
     notifCleaningActive: PropTypes.bool,
@@ -41,10 +41,6 @@ export default class ColumnHeader extends React.PureComponent {
     intl: PropTypes.object.isRequired,
   };
 
-  static defaultProps = {
-    focusable: true,
-  }
-
   state = {
     collapsed: true,
     animating: false,
@@ -91,7 +87,7 @@ export default class ColumnHeader extends React.PureComponent {
   }
 
   render () {
-    const { intl, icon, active, children, pinned, onPin, multiColumn, focusable, showBackButton, intl: { formatMessage }, notifCleaning, notifCleaningActive } = this.props;
+    const { intl, icon, active, children, pinned, onPin, multiColumn, extraButton, showBackButton, intl: { formatMessage }, notifCleaning, notifCleaningActive } = this.props;
     const { collapsed, animating, animatingNCD } = this.state;
 
     let title = this.props.title;
@@ -167,18 +163,26 @@ export default class ColumnHeader extends React.PureComponent {
     }
 
     if (children || multiColumn) {
-      collapseButton = <button className={collapsibleButtonClassName} aria-label={formatMessage(collapsed ? messages.show : messages.hide)} aria-pressed={collapsed ? 'false' : 'true'} onClick={this.handleToggleClick}><i className='fa fa-sliders' /></button>;
+      collapseButton = <button className={collapsibleButtonClassName} title={formatMessage(collapsed ? messages.show : messages.hide)} aria-label={formatMessage(collapsed ? messages.show : messages.hide)} aria-pressed={collapsed ? 'false' : 'true'} onClick={this.handleToggleClick}><i className='fa fa-sliders' /></button>;
     }
 
+    const hasTitle = icon && title;
+
     return (
       <div className={wrapperClassName}>
-        <h1 tabIndex={focusable ? 0 : null} role='button' className={buttonClassName} aria-label={title} onClick={this.handleTitleClick}>
-          <i className={`fa fa-fw fa-${icon} column-header__icon`} />
-          <span className='column-header__title'>
-            {title}
-          </span>
+        <h1 className={buttonClassName}>
+          {hasTitle && (
+            <button onClick={this.handleTitleClick}>
+              <i className={`fa fa-fw fa-${icon} column-header__icon`} />
+              {title}
+            </button>
+          )}
+
+          {!hasTitle && backButton}
+
           <div className='column-header__buttons'>
-            {backButton}
+            {hasTitle && backButton}
+            {extraButton}
             { notifCleaning ? (
               <button
                 aria-label={msgEnterNotifCleaning}
diff --git a/app/javascript/flavours/glitch/components/status_content.js b/app/javascript/flavours/glitch/components/status_content.js
index 3bb3c7a12..32b0770cb 100644
--- a/app/javascript/flavours/glitch/components/status_content.js
+++ b/app/javascript/flavours/glitch/components/status_content.js
@@ -11,7 +11,8 @@ export default class StatusContent extends React.PureComponent {
   static propTypes = {
     status: ImmutablePropTypes.map.isRequired,
     expanded: PropTypes.bool,
-    setExpansion: PropTypes.func,
+    collapsed: PropTypes.bool,
+    onExpandedToggle: PropTypes.func,
     media: PropTypes.element,
     mediaIcon: PropTypes.string,
     parseClick: PropTypes.func,
@@ -64,7 +65,7 @@ export default class StatusContent extends React.PureComponent {
   }
 
   onLinkClick = (e) => {
-    if (this.props.expanded === false) {
+    if (this.props.collapsed) {
       if (this.props.parseClick) this.props.parseClick(e);
     }
   }
@@ -111,8 +112,8 @@ export default class StatusContent extends React.PureComponent {
   handleSpoilerClick = (e) => {
     e.preventDefault();
 
-    if (this.props.setExpansion) {
-      this.props.setExpansion(this.props.expanded ? null : true);
+    if (this.props.onExpandedToggle) {
+      this.props.onExpandedToggle();
     } else {
       this.setState({ hidden: !this.state.hidden });
     }
@@ -131,7 +132,7 @@ export default class StatusContent extends React.PureComponent {
       disabled,
     } = this.props;
 
-    const hidden = this.props.setExpansion ? !this.props.expanded : this.state.hidden;
+    const hidden = this.props.onExpandedToggle ? !this.props.expanded : this.state.hidden;
 
     const content = { __html: status.get('contentHtml') };
     const spoilerContent = { __html: status.get('spoilerHtml') };
diff --git a/app/javascript/flavours/glitch/components/status_icons.js b/app/javascript/flavours/glitch/components/status_icons.js
index 4f585175c..e354c45e4 100644
--- a/app/javascript/flavours/glitch/components/status_icons.js
+++ b/app/javascript/flavours/glitch/components/status_icons.js
@@ -22,15 +22,15 @@ export default class StatusIcons extends React.PureComponent {
     mediaIcon: PropTypes.string,
     collapsible: PropTypes.bool,
     collapsed: PropTypes.bool,
-    setExpansion: PropTypes.func.isRequired,
+    setCollapsed: PropTypes.func.isRequired,
     intl: PropTypes.object.isRequired,
   };
 
   //  Handles clicks on collapsed button
   handleCollapsedClick = (e) => {
-    const { collapsed, setExpansion } = this.props;
+    const { collapsed, setCollapsed } = this.props;
     if (e.button === 0) {
-      setExpansion(collapsed ? null : false);
+      setCollapsed(!collapsed);
       e.preventDefault();
     }
   }
diff --git a/app/javascript/flavours/glitch/features/status/components/detailed_status.js b/app/javascript/flavours/glitch/features/status/components/detailed_status.js
index 066499da8..16f7ae830 100644
--- a/app/javascript/flavours/glitch/features/status/components/detailed_status.js
+++ b/app/javascript/flavours/glitch/features/status/components/detailed_status.js
@@ -24,6 +24,8 @@ export default class DetailedStatus extends ImmutablePureComponent {
     settings: ImmutablePropTypes.map.isRequired,
     onOpenMedia: PropTypes.func.isRequired,
     onOpenVideo: PropTypes.func.isRequired,
+    onToggleHidden: PropTypes.func.isRequired,
+    expanded: PropTypes.bool,
   };
 
   handleAccountClick = (e) => {
@@ -41,7 +43,7 @@ export default class DetailedStatus extends ImmutablePureComponent {
 
   render () {
     const status = this.props.status.get('reblog') ? this.props.status.get('reblog') : this.props.status;
-    const { expanded, setExpansion, settings } = this.props;
+    const { expanded, onToggleHidden, settings } = this.props;
 
     let media           = '';
     let mediaIcon       = null;
@@ -114,7 +116,8 @@ export default class DetailedStatus extends ImmutablePureComponent {
           media={media}
           mediaIcon={mediaIcon}
           expanded={expanded}
-          setExpansion={setExpansion}
+          collapsed={false}
+          onExpandedToggle={onToggleHidden}
         />
 
         <div className='detailed-status__meta'>
diff --git a/app/javascript/flavours/glitch/features/status/index.js b/app/javascript/flavours/glitch/features/status/index.js
index 717f99d4a..7e1658dbb 100644
--- a/app/javascript/flavours/glitch/features/status/index.js
+++ b/app/javascript/flavours/glitch/features/status/index.js
@@ -29,6 +29,7 @@ import { initReport } from 'flavours/glitch/actions/reports';
 import { makeGetStatus } from 'flavours/glitch/selectors';
 import { ScrollContainer } from 'react-router-scroll-4';
 import ColumnBackButton from 'flavours/glitch/components/column_back_button';
+import ColumnHeader from '../../components/column_header';
 import StatusContainer from 'flavours/glitch/containers/status_container';
 import { openModal } from 'flavours/glitch/actions/modal';
 import { defineMessages, injectIntl, FormattedMessage } from 'react-intl';
@@ -41,6 +42,8 @@ const messages = defineMessages({
   deleteConfirm: { id: 'confirmations.delete.confirm', defaultMessage: 'Delete' },
   deleteMessage: { id: 'confirmations.delete.message', defaultMessage: 'Are you sure you want to delete this status?' },
   blockConfirm: { id: 'confirmations.block.confirm', defaultMessage: 'Block' },
+  revealAll: { id: 'status.show_more_all', defaultMessage: 'Show more for all' },
+  hideAll: { id: 'status.show_less_all', defaultMessage: 'Show less for all' },
 });
 
 const makeMapStateToProps = () => {
@@ -76,7 +79,8 @@ export default class Status extends ImmutablePureComponent {
 
   state = {
     fullscreen: false,
-    isExpanded: null,
+    isExpanded: false,
+    threadExpanded: null,
   };
 
   componentWillMount () {
@@ -96,7 +100,7 @@ export default class Status extends ImmutablePureComponent {
 
   handleExpandedToggle = () => {
     if (this.props.status.get('spoiler_text')) {
-      this.setExpansion(this.state.isExpanded ? null : true);
+      this.setExpansion(!this.state.isExpanded);
     }
   };
 
@@ -190,6 +194,11 @@ export default class Status extends ImmutablePureComponent {
     }
   }
 
+  handleToggleAll = () => {
+    const { isExpanded } = this.state;
+    this.setState({ isExpanded: !isExpanded, threadExpanded: !isExpanded });
+  }
+
   handleBlockClick = (account) => {
     const { dispatch, intl } = this.props;
 
@@ -285,6 +294,7 @@ export default class Status extends ImmutablePureComponent {
       <StatusContainer
         key={id}
         id={id}
+        expanded={this.state.threadExpanded}
         onMoveUp={this.handleMoveUp}
         onMoveDown={this.handleMoveDown}
       />
@@ -292,7 +302,7 @@ export default class Status extends ImmutablePureComponent {
   }
 
   setExpansion = value => {
-    this.setState({ isExpanded: value ? true : null });
+    this.setState({ isExpanded: value });
   }
 
   setRef = c => {
@@ -327,7 +337,7 @@ export default class Status extends ImmutablePureComponent {
   render () {
     let ancestors, descendants;
     const { setExpansion } = this;
-    const { status, settings, ancestorsIds, descendantsIds } = this.props;
+    const { status, settings, ancestorsIds, descendantsIds, intl } = this.props;
     const { fullscreen, isExpanded } = this.state;
 
     if (status === null) {
@@ -360,7 +370,12 @@ export default class Status extends ImmutablePureComponent {
 
     return (
       <Column>
-        <ColumnBackButton />
+        <ColumnHeader
+          showBackButton
+          extraButton={(
+            <button className='column-header__button' title={intl.formatMessage(!isExpanded ? messages.revealAll : messages.hideAll)} aria-label={intl.formatMessage(!isExpanded ? messages.revealAll : messages.hideAll)} onClick={this.handleToggleAll} aria-pressed={!isExpanded ? 'false' : 'true'}><i className={`fa fa-${!isExpanded ? 'eye-slash' : 'eye'}`} /></button>
+          )}
+        />
 
         <ScrollContainer scrollKey='thread'>
           <div className={classNames('scrollable', 'detailed-status__wrapper', { fullscreen })} ref={this.setRef}>
@@ -374,7 +389,7 @@ export default class Status extends ImmutablePureComponent {
                   onOpenVideo={this.handleOpenVideo}
                   onOpenMedia={this.handleOpenMedia}
                   expanded={isExpanded}
-                  setExpansion={setExpansion}
+                  onToggleHidden={this.handleExpandedToggle}
                 />
 
                 <ActionBar
diff --git a/app/javascript/flavours/glitch/features/ui/components/column_header.js b/app/javascript/flavours/glitch/features/ui/components/column_header.js
index af195ea9c..e8bdd8054 100644
--- a/app/javascript/flavours/glitch/features/ui/components/column_header.js
+++ b/app/javascript/flavours/glitch/features/ui/components/column_header.js
@@ -1,5 +1,6 @@
 import React from 'react';
 import PropTypes from 'prop-types';
+import classNames from 'classnames';
 
 export default class ColumnHeader extends React.PureComponent {
 
@@ -16,19 +17,20 @@ export default class ColumnHeader extends React.PureComponent {
   }
 
   render () {
-    const { type, active, columnHeaderId } = this.props;
+    const { icon, type, active, columnHeaderId } = this.props;
+    let iconElement = '';
 
-    let icon = '';
-
-    if (this.props.icon) {
-      icon = <i className={`fa fa-fw fa-${this.props.icon} column-header__icon`} />;
+    if (icon) {
+      iconElement = <i className={`fa fa-fw fa-${icon} column-header__icon`} />;
     }
 
     return (
-      <div role='heading' tabIndex='0' className={`column-header ${active ? 'active' : ''}`} onClick={this.handleClick} id={columnHeaderId || null}>
-        {icon}
-        {type}
-      </div>
+      <h1 className={classNames('column-header', { active })} id={columnHeaderId || null}>
+        <button onClick={this.handleClick}>
+          {iconElement}
+          {type}
+        </button>
+      </h1>
     );
   }
 
diff --git a/app/javascript/flavours/glitch/reducers/statuses.js b/app/javascript/flavours/glitch/reducers/statuses.js
index f14fcea1e..bc5bc1804 100644
--- a/app/javascript/flavours/glitch/reducers/statuses.js
+++ b/app/javascript/flavours/glitch/reducers/statuses.js
@@ -62,16 +62,20 @@ const normalizeStatus = (state, status) => {
     normalStatus.reblog = status.reblog.id;
   }
 
-  const searchContent = [status.spoiler_text, status.content].join('\n\n').replace(/<br \/>/g, '\n').replace(/<\/p><p>/g, '\n\n');
+  // Only calculate these values when status first encountered
+  // Otherwise keep the ones already in the reducer
+  if (!state.has(status.id)) {
+    const searchContent = [status.spoiler_text, status.content].join('\n\n').replace(/<br \/>/g, '\n').replace(/<\/p><p>/g, '\n\n');
 
-  const emojiMap = normalStatus.emojis.reduce((obj, emoji) => {
-    obj[`:${emoji.shortcode}:`] = emoji;
-    return obj;
-  }, {});
+    const emojiMap = normalStatus.emojis.reduce((obj, emoji) => {
+      obj[`:${emoji.shortcode}:`] = emoji;
+      return obj;
+    }, {});
 
-  normalStatus.search_index = domParser.parseFromString(searchContent, 'text/html').documentElement.textContent;
-  normalStatus.contentHtml = emojify(normalStatus.content, emojiMap);
-  normalStatus.spoilerHtml = emojify(escapeTextContentForBrowser(normalStatus.spoiler_text || ''), emojiMap);
+    normalStatus.search_index = domParser.parseFromString(searchContent, 'text/html').documentElement.textContent;
+    normalStatus.contentHtml  = emojify(normalStatus.content, emojiMap);
+    normalStatus.spoilerHtml  = emojify(escapeTextContentForBrowser(normalStatus.spoiler_text || ''), emojiMap);
+  }
 
   return state.update(status.id, ImmutableMap(), map => map.mergeDeep(fromJS(normalStatus)));
 };
diff --git a/app/javascript/flavours/glitch/styles/components/columns.scss b/app/javascript/flavours/glitch/styles/components/columns.scss
index 5dcfab4d1..34175685e 100644
--- a/app/javascript/flavours/glitch/styles/components/columns.scss
+++ b/app/javascript/flavours/glitch/styles/components/columns.scss
@@ -243,7 +243,6 @@
 .column-header {
   display: flex;
   font-size: 16px;
-  padding: 15px;
   background: lighten($ui-base-color, 4%);
   flex: 0 0 auto;
   cursor: pointer;
@@ -255,7 +254,7 @@
   & > button {
     margin: 0;
     border: none;
-    padding: 15px 0 15px 15px;
+    padding: 15px;
     color: inherit;
     background: transparent;
     font: inherit;
@@ -266,6 +265,10 @@
     flex: 1;
   }
 
+  & > .column-header__back-button {
+    color: $ui-highlight-color;
+  }
+
   &.active {
     box-shadow: 0 1px 0 rgba($ui-highlight-color, 0.3);
 
@@ -303,7 +306,6 @@
 .column-header__buttons {
   height: 48px;
   display: flex;
-  margin: -15px;
   margin-left: 0;
 }
diff --git a/app/javascript/flavours/glitch/components/status.js b/app/javascript/flavours/glitch/components/status.js
index 120772201..a6c08ba1c 100644
--- a/app/javascript/flavours/glitch/components/status.js
+++ b/app/javascript/flavours/glitch/components/status.js
@@ -47,10 +47,12 @@ export default class Status extends ImmutablePureComponent {
     onMoveDown: PropTypes.func,
     getScrollPosition: PropTypes.func,
     updateScrollBottom: PropTypes.func,
+    expanded: PropTypes.bool,
   };
 
   state = {
-    isExpanded: null,
+    isExpanded: this.props.expanded,
+    isCollapsed: false,
     autoCollapsed: false,
   }
 
@@ -71,6 +73,7 @@ export default class Status extends ImmutablePureComponent {
 
   updateOnStates = [
     'isExpanded',
+    'isCollapsed',
   ]
 
   //  If our settings have changed to disable collapsed statuses, then we
@@ -83,18 +86,21 @@ export default class Status extends ImmutablePureComponent {
   //  uncollapse our status accordingly.
   componentWillReceiveProps (nextProps) {
     if (!nextProps.settings.getIn(['collapsed', 'enabled'])) {
-      if (this.state.isExpanded === false) {
-        this.setExpansion(null);
+      if (this.state.isCollapsed) {
+        this.setCollapsed(false);
       }
     } else if (
       nextProps.collapse !== this.props.collapse &&
       nextProps.collapse !== undefined
-    ) this.setExpansion(nextProps.collapse ? false : null);
+    ) this.setCollapsed(nextProps.collapse);
+    if (nextProps.expanded !== this.props.expanded &&
+      nextProps.expanded !== undefined
+    ) this.setExpansion(nextProps.expanded);
   }
 
   //  When mounting, we just check to see if our status should be collapsed,
   //  and collapse it if so. We don't need to worry about whether collapsing
   //  is enabled here, because `setExpansion()` already takes that into
   //  account.
 
   //  The cases where a status should be collapsed are:
@@ -138,7 +144,7 @@ export default class Status extends ImmutablePureComponent {
         return false;
       }
     }()) {
-      this.setExpansion(false);
+      this.setCollapsed(true);
       // Hack to fix timeline jumps on second rendering when auto-collapsing
       this.setState({ autoCollapsed: true });
     }
@@ -164,23 +170,26 @@ export default class Status extends ImmutablePureComponent {
     }
   }
 
-  //  `setExpansion()` sets the value of `isExpanded` in our state. It takes
-  //  one argument, `value`, which gives the desired value for `isExpanded`.
-  //  The default for this argument is `null`.
+  //  `setCollapsed()` sets the value of `isCollapsed` in our state, that is,
+  //  whether the toot is collapsed or not.
 
   //  `setExpansion()` automatically checks for us whether toot collapsing
   //  is enabled, so we don't have to.
+  setCollapsed = (value) => {
+    if (this.props.settings.getIn(['collapsed', 'enabled'])) {
+      this.setState({ isCollapsed: value });
+      if (value) {
+        this.setExpansion(false);
+      }
+    } else {
+      this.setState({ isCollapsed: false });
+    }
+  }
+
   setExpansion = (value) => {
-    switch (true) {
-    case value === undefined || value === null:
-      this.setState({ isExpanded: null });
-      break;
-    case !value && this.props.settings.getIn(['collapsed', 'enabled']):
-      this.setState({ isExpanded: false });
-      break;
-    case !!value:
-      this.setState({ isExpanded: true });
-      break;
+    this.setState({ isExpanded: value });
+    if (value) {
+      this.setCollapsed(false);
     }
   }
 
@@ -192,7 +201,7 @@ export default class Status extends ImmutablePureComponent {
   parseClick = (e, destination) => {
     const { router } = this.context;
     const { status } = this.props;
-    const { isExpanded } = this.state;
+    const { isCollapsed } = this.state;
     if (!router) return;
     if (destination === undefined) {
       destination = `/statuses/${
@@ -200,9 +209,9 @@ export default class Status extends ImmutablePureComponent {
       }`;
     }
     if (e.button === 0) {
-      if (isExpanded === false) this.setExpansion(null);
+      if (isCollapsed) this.setCollapsed(false);
       else if (e.shiftKey) {
-        this.setExpansion(false);
+        this.setCollapsed(true);
         document.getSelection().removeAllRanges();
       } else router.history.push(destination);
       e.preventDefault();
@@ -219,7 +228,7 @@ export default class Status extends ImmutablePureComponent {
 
   handleExpandedToggle = () => {
     if (this.props.status.get('spoiler_text')) {
-      this.setExpansion(this.state.isExpanded ? null : true);
+      this.setExpansion(!this.state.isExpanded);
     }
   };
 
@@ -278,6 +287,7 @@ export default class Status extends ImmutablePureComponent {
       handleRef,
       parseClick,
       setExpansion,
+      setCollapsed,
     } = this;
     const { router } = this.context;
     const {
@@ -295,7 +305,7 @@ export default class Status extends ImmutablePureComponent {
       featured,
       ...other
     } = this.props;
-    const { isExpanded } = this.state;
+    const { isExpanded, isCollapsed } = this.state;
     let background = null;
     let attachments = null;
     let media = null;
@@ -414,8 +424,8 @@ export default class Status extends ImmutablePureComponent {
     };
 
     const computedClass = classNames('status', `status-${status.get('visibility')}`, {
-      collapsed: isExpanded === false,
-      'has-background': isExpanded === false && background,
+      collapsed: isCollapsed,
+      'has-background': isCollapsed && background,
       muted,
     }, 'focusable');
 
@@ -423,7 +433,7 @@ export default class Status extends ImmutablePureComponent {
       <HotKeys handlers={handlers}>
         <div
           className={computedClass}
-          style={isExpanded === false && background ? { backgroundImage: `url(${background})` } : null}
+          style={isCollapsed && background ? { backgroundImage: `url(${background})` } : null}
           {...selectorAttribs}
           ref={handleRef}
           tabIndex='0'
@@ -439,11 +449,11 @@ export default class Status extends ImmutablePureComponent {
                   notificationId={this.props.notificationId}
                 />
               ) : null}
-              {!muted || isExpanded !== false ? (
+              {!muted || !isCollapsed ? (
                 <StatusHeader
                   status={status}
                   friend={account}
-                  collapsed={isExpanded === false}
+                  collapsed={isCollapsed}
                   parseClick={parseClick}
                 />
               ) : null}
@@ -452,8 +462,8 @@ export default class Status extends ImmutablePureComponent {
               status={status}
               mediaIcon={mediaIcon}
               collapsible={settings.getIn(['collapsed', 'enabled'])}
-              collapsed={isExpanded === false}
-              setExpansion={setExpansion}
+              collapsed={isCollapsed}
+              setCollapsed={setCollapsed}
             />
           </header>
           <StatusContent
@@ -461,11 +471,11 @@ export default class Status extends ImmutablePureComponent {
             media={media}
             mediaIcon={mediaIcon}
             expanded={isExpanded}
-            setExpansion={setExpansion}
+            onExpandedToggle={this.handleExpandedToggle}
             parseClick={parseClick}
             disabled={!router}
           />
-          {isExpanded !== false || !muted ? (
+          {!isCollapsed || !muted ? (
             <StatusActionBar
               {...other}
               status={status}
@@ -83,18 +86,21 @@ export default class Status extends ImmutablePureComponent {
   //  When mounting, we just check to see if our status should be collapsed,
   //  and collapse it if so. We don't need to worry about whether collapsing
-  //  is enabled here, because `setExpansion()` already takes that into
+  //  is enabled here, because `setCollapsed()` already takes that into
   //  account.
 
@@ -164,23 +170,26 @@ export default class Status extends ImmutablePureComponent {
 
-  //  `setExpansion()` automatically checks for us whether toot collapsing
+  //  `setCollapsed()` automatically checks for us whether toot collapsing
   //  is enabled, so we don't have to.